@@ -1,7 +1,7 @@
 # Yahoo.pm
 # by Martin Thurn
 # Copyright (C) 1996-1998 by USC/ISI
-# $Id: Yahoo.pm,v 2.359 2004/09/25 01:44:23 Daddy Exp $
+# $Id: Yahoo.pm,v 2.361 2005/07/03 01:19:51 Daddy Exp $
 
 =head1 NAME
 
@@ -114,7 +114,7 @@ use vars qw( $VERSION $MAINTAINER @ISA );
 use vars qw( $iMustPause );
 
 @ISA = qw( WWW::Search );
-$VERSION = do { my @r = (q$Revision: 2.359 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.361 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 # Thanks to the hard work of Gil Vidals and his team at
@@ -333,12 +333,13 @@ sub parse_tree
     if ($self->_a_is_next_link($oA))
       {
       my $sURL = $oA->attr('href');
-      printf STDERR " +   raw    next URL ==$sURL==\n" if (2 <= $self->{_debug});
+      print STDERR " +   raw     next URL ==$sURL==\n" if (2 <= $self->{_debug});
       # Delete Yahoo-redirect portion of URL:
-      $sURL =~ s!\A.+?\*?-?(?=http)!!;
+      $sURL =~ s!\A.+?[-*]+(?=http)!!;
+      print STDERR " +   poached next URL ==$sURL==\n" if (2 <= $self->{_debug});
       $sURL =~ s!\Ahttp%3A!http:!i;
       $self->{_next_url} = $self->absurl($self->{'_prev_url'}, $sURL);
-      printf STDERR " +   cooked next URL ==$self->{_next_url}==\n" if (2 <= $self->{_debug});
+      print STDERR " +   cooked  next URL ==$self->{_next_url}==\n" if (2 <= $self->{_debug});
       last NEXT_A;
       } # if
     } # foreach NEXT_A
@@ -399,3 +400,4 @@ http://google.yahoo.com/bin/query?p=%22Shelagh+Fraser%22&b=21&hc=0&hs=0&xargs=
 _next_url :
 
 http://google.yahoo.com/bin/query?%0Ap=%22Shelagh+Fraser%22&b=21&hc=0&hs=0&xargs=
+
